Skip to contents

This function calculates the proportion of identical scores and mean absolute error of rubric items between two Gradescope evaluation csv

Usage

compute_mae_and_isp(file1, file2)

Arguments

file1

file path for first grades csv

file2

file path for second grades csv

Value

a list