Validate Metadata JSON
validate_metadata_json.RdThis function validates a JSON file that stores metadata about the assignment, its course and rubric items. The contents of the saved JSON file can be printed out.
validate_metadata_json.RdThis function validates a JSON file that stores metadata about the assignment, its course and rubric items. The contents of the saved JSON file can be printed out.