Deidentify Graders
deidentify_graders.RdThis function swaps the original grader names with fake names from a roster and saves the deidentified grades as a csv and the lookup table for the graders as a csv.
deidentify_graders.RdThis function swaps the original grader names with fake names from a roster and saves the deidentified grades as a csv and the lookup table for the graders as a csv.