Generate Rubric Texts
generate_rubric_texts.RdThis function generates or updated the rubric_items.csv with a grades csv file's rubric items. The grades csv is saved with "R1", "R2", ... labels for the rubric items as a new csv, and this function returns this new grades csv as a dataframe.
Usage
generate_rubric_texts(
csv_path,
output_folder,
ignored_nrows = 3,
existing = TRUE,
pensieve = FALSE
)