Normalize Full Credit
normalize_full_credit.RdThis function "normalizes" the "Full Credit" toggle
on the evaluations by making all other rubric items
TRUE to allow for comparisons across individual rubric
items. Note that rubric_items can be a string vector of
column names or a numeric vector of column indices.